pub enum TabKeyBehavior {
Tab,
Spaces,
}Expand description
Controls how a Tab key press is handled by the editor when using EditCommand::InsertTab.
Variants
Tab
Insert a literal tab character ('\t').
Spaces
Insert spaces up to the next tab stop (based on the current tab_width setting).