pub struct UndoHistoryTextEdit {
pub start_before: usize,
pub start_after: usize,
pub deleted_text: String,
pub inserted_text: String,
}Expand description
A single persisted text edit in an undo/redo step.
Fields
start_before: usizeStart offset in the document before applying the edit.
start_after: usizeStart offset in the document after applying the edit.
deleted_text: StringDeleted text (from the pre-edit document).
inserted_text: StringInserted text (from the post-edit document).