TextDeltaEdit

Struct TextDeltaEdit 

pub struct TextDeltaEdit {
    pub start: usize,
    pub deleted_text: String,
    pub inserted_text: String,
}
A single text edit expressed in character offsets.

Semantics:

  • start is a character offset in the document at the time this edit is applied.
  • The deleted range is defined by the length (in chars) of deleted_text.
  • Edits inside a TextDelta must be applied in order to transform the “before” document into the “after” document.

Fields

start: usize

Start character offset of the edit.

deleted_text: String

Exact deleted text (may be empty).

inserted_text: String

Exact inserted text (may be empty).

Implementations

Source

impl TextDeltaEdit

pub fn deleted_len(&self) -> usize

Length of deleted_text in characters.

pub fn inserted_len(&self) -> usize

Length of inserted_text in characters.

pub fn end(&self) -> usize

Exclusive end character offset in the pre-edit document.