Module line_ending

Module line_ending 

Line ending helpers.

editor-core stores text internally using LF ('\n') newlines. When opening a file that uses CRLF ("\r\n"), the content is normalized on load, but the preferred line ending can be tracked for saving.

Enums

LineEnding
The preferred newline sequence used when saving a document.