ComposedCellSource

Enum ComposedCellSource 

pub enum ComposedCellSource {
    Document {
        offset: usize,
    },
    Virtual {
        anchor_offset: usize,
    },
}
The origin of a composed cell.

Variants



Document

A document text character at the given character offset.

Fields

offset: usize

Character offset (Unicode scalar values) from the start of the document.



Virtual

A virtual cell anchored to a document character offset (e.g. inlay hints, code lens).

Fields

anchor_offset: usize

Anchor character offset in the document.