ComposedLineKind

Enum ComposedLineKind 

pub enum ComposedLineKind {
    Document {
        logical_line: usize,
        visual_in_logical: usize,
    },
    VirtualAboveLine {
        logical_line: usize,
    },
}
The kind of a composed visual line.

Variants



Document

A line segment that corresponds to actual document text (wrap + folding aware).

Fields

logical_line: usize

Logical line index.

visual_in_logical: usize

Which wrapped segment within the logical line (0-based).



VirtualAboveLine

A virtual line inserted above a logical line (e.g. code lens).

Fields

logical_line: usize

Logical line index that this virtual line is associated with.