SymbolKind

Enum SymbolKind 

pub enum SymbolKind {
Show 27 variants File, Module, Namespace, Package, Class, Method, Property, Field, Constructor, Enum, Interface, Function, Variable, Constant, String, Number, Boolean, Array, Object, Key, Null, EnumMember, Struct, Event, Operator, TypeParameter, Custom(u32),
}
A coarse symbol kind tag.

Variants



File

A file-level symbol.



Module

A module symbol.



Namespace

A namespace symbol.



Package

A package symbol.



Class

A class symbol.



Method

A method symbol.



Property

A property symbol.



Field

A field symbol.



Constructor

A constructor symbol.



Enum

An enum symbol.



Interface

An interface symbol.



Function

A function symbol.



Variable

A variable symbol.



Constant

A constant symbol.



String

A string literal / string-like symbol.



Number

A numeric symbol.



Boolean

A boolean symbol.



Array

An array symbol.



Object

An object symbol.



Key

A key symbol.



Null

A null symbol.



EnumMember

An enum member symbol.



Struct

A struct symbol.



Event

An event symbol.



Operator

An operator symbol.



TypeParameter

A type parameter symbol.



Custom(u32)

An integration-defined kind value.

Implementations

Source

impl SymbolKind

pub fn from_lsp_kind(kind: u32) -> Self

Convert an LSP SymbolKind numeric value into a SymbolKind.