pub struct TextDeltaEdit {
pub start: usize,
pub deleted_text: String,
pub inserted_text: String,
}Expand description
A single text edit expressed in character offsets.
Semantics:
startis a character offset in the document at the time this edit is applied.- The deleted range is defined by the length (in
chars) ofdeleted_text. - Edits inside a
TextDeltamust be applied in order to transform the “before” document into the “after” document.
Fields
start: usizeStart character offset of the edit.
deleted_text: StringExact deleted text (may be empty).
inserted_text: StringExact inserted text (may be empty).
Implementations
Sourceimpl TextDeltaEdit
impl TextDeltaEdit
Sourcepub fn deleted_len(&self) -> usize
pub fn deleted_len(&self) -> usize
Length of deleted_text in characters.
Sourcepub fn inserted_len(&self) -> usize
pub fn inserted_len(&self) -> usize
Length of inserted_text in characters.