pub enum ComposedCellSource {
Document {
offset: usize,
},
Virtual {
anchor_offset: usize,
},
}Expand description
The origin of a composed cell.
Variants
Document
A document text character at the given character offset.
Virtual
A virtual cell anchored to a document character offset (e.g. inlay hints, code lens).