pub enum ComposedLineKind {
Document {
logical_line: usize,
visual_in_logical: usize,
},
VirtualAboveLine {
logical_line: usize,
},
}Expand description
The kind of a composed visual line.
Variants
Document
A line segment that corresponds to actual document text (wrap + folding aware).
Fields
VirtualAboveLine
A virtual line inserted above a logical line (e.g. code lens).